/*
	bfsha1 - Brute forces a SHA1 hash
	Copyright (C) 2012 Steve Thomas <steve AT tobtu DOT com>

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef CUDA_COMMON_H
#define CUDA_COMMON_H

#include "common.h"
#include <cuda_runtime_api.h>

#define checkCudaErrors(err) \
            __checkCudaErrors(            err,         __FILE__,       __LINE__)
inline void __checkCudaErrors(cudaError_t err, const char *file, const int line)
{
    if (cudaSuccess != err)
	{
		reportError("%s(%i) : CUDA Runtime API error %d: %s.\n",
			file, line, (int) err, cudaGetErrorString(err));
        exit(1);
    }
}

#define getLastCudaError(msg) \
            __getLastCudaError(            msg,         __FILE__,       __LINE__)
inline void __getLastCudaError(const char *msg, const char *file, const int line)
{
    cudaError_t err = cudaGetLastError();
    if (cudaSuccess != err)
	{
		reportError("%s(%i) : getLastCudaError() CUDA error : %s : (%d) %s.\n",
			file, line, msg, (int) err, cudaGetErrorString(err));
        exit(1);
    }
}

typedef void (*kernel_cracker)(int blocks, int threads, uint32_t *d_shared, uint32_t *d_foundPw, uint32_t pwLen, uint32_t char2Start, uint32_t char2End, uint64_t index, uint64_t maxIndex);

int versionToCores(int major, int minor);
void getDefaultBlocksThreads(int deviceId, int &blocks, int &threads);
void setDefaultBlocksThreads(int deviceId, int  blocks, int  threads);
void setDefaultBlocks       (int deviceId, int  blocks);
void setDefaultThreads      (int deviceId,              int  threads);

#endif
